@@ -38,6 +38,8 @@ extern struct astime_state state;
 int withdrawn = 0;
 int iconic = 0;
 int pushed_in = 1;
+int no_border = 0;
+
 char display_name[MAX_OPT_LEN];
 char mainGeometry[MAX_OPT_LEN];
 char window_name[MAX_OPT_LEN];
@@ -68,6 +70,8 @@ void defaults()
 	withdrawn = 0;
 	iconic = 0;
 	pushed_in = 1;
+	no_border = 0;
+	
 	state.total_size.x = state.total_size.y = 54;
 	safecopy(window_name, "astime", MAX_OPT_LEN);
 	safecopy(display_name, "", MAX_OPT_LEN);
@@ -130,6 +134,7 @@ void usage()
 	printf("-withdrawn       start in withdrawn shape (for WindowMaker)\n");
 	printf("-iconic          start iconized\n");
 	printf("-standout        standing out rather than being pushed in\n");
+	printf("-noborder        no shaded border at all, thank you very much\n");
 	printf("-shift <hrs>     show the time with the given shift in hours\n");
 	printf("-title <name>    set the window/icon title to this name\n");
 	printf("-bg <color>      background color\n");
@@ -163,7 +168,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-	printf("astime : AfterStep analog clock version 2.6\n");
+	printf("astime : AfterStep analog clock version 2.7\n");
 }
 
 /* parse the rc file */
@@ -373,6 +378,10 @@ void parsercfile(FILE * ifp)
 				tval = atoi(param[1]);
 				if (tval)
 					pushed_in = 0;
+			} else if (!strcmp(param[0], "noborder")) {
+				tval = atoi(param[1]);
+				if (tval)
+					no_border = 1;
 			} else if (!strcmp(param[0], "shift")) {
 				state.shift = atoi(param[1]);
 				if ((state.shift > 23) || (state.shift < -23))
@@ -405,6 +414,8 @@ void parsecmdline(int argc, char *argv[])
 				iconic = 1;
 			} else if (!strncmp(argument, "-standout", 9)) {
 				pushed_in = 0;
+			} else if (!strncmp(argument, "-noborder", 9)) {
+				no_border = 1;
 			} else if (!strncmp(argument, "-u", 2)) {
 				if (++i >= argc)
 					usage();
@@ -619,7 +630,8 @@ int main(int argc, char **argv)
 		   mainGeometry,
 		   withdrawn,
 		   iconic,
-		   pushed_in);
+		   pushed_in,
+		   no_border);
 	while (1) {
 		update();
 		usleep(X11_INTERVAL);
